Package: MsDataHub
Title: Mass Spectrometry Data on ExperimentHub
Version: 1.10.0
Authors@R: 
    c(person(given = "Laurent",
             family = "Gatto",
             email = "laurent.gatto@uclouvain.be",
             role = c("aut", "cre"),
             comment = c(ORCID = "0000-0002-1520-2268")),
      person(given = "Kristina",
             family = "Gomoryova",
             role = "ctb",
             comment = c(ORCID = "0000-0003-4407-3917")),
      person(given = "Johannes",
             family = "Rainer",
             email = "Johannes.Rainer@eurac.edu",
             role = "aut",
             comment = c(ORCID = "0000-0002-6977-7147")))
Description: The MsDataHub package uses the ExperimentHub
             infrastructure to distribute raw mass spectrometry data
             files, peptide spectrum matches or quantitative data from
             proteomics and metabolomics experiments.
License: Artistic-2.0
BugReports: https://github.com/RforMassSpectrometry/MsDataHub/issues
URL: https://rformassspectrometry.github.io/MsDataHub
Imports: ExperimentHub, utils
Suggests: ExperimentHubData, DT, BiocStyle, knitr, rmarkdown, testthat
        (>= 3.0.0), Spectra, mzR, PSMatch, QFeatures (>= 1.13.3)
biocViews: ExperimentHubSoftware, MassSpectrometry, Proteomics,
        Metabolomics
Encoding: UTF-8
VignetteBuilder: knitr
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/MsDataHub
git_branch: RELEASE_3_22
git_last_commit: c362bfe
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 05:19:20 UTC; biocbuild
Author: Laurent Gatto [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-1520-2268>),
  Kristina Gomoryova [ctb] (ORCID:
    <https://orcid.org/0000-0003-4407-3917>),
  Johannes Rainer [aut] (ORCID: <https://orcid.org/0000-0002-6977-7147>)
Maintainer: Laurent Gatto <laurent.gatto@uclouvain.be>
